/**
 * Documentation: http://docs.azk.io/Azkfile.js
 */
// Adds the systems that shape your system
systems({
	web: {
		// Dependent systems
		depends: ["mysql"],
		// More images:  http://images.azk.io
		image: {"docker": "azukiapp/php-fpm"},
		workdir: "/var/www",
		shell: "/bin/bash",
		wait: {"retry": 20, "timeout": 1000},
		mounts: {
			'/var/www': path(".")
		},
		scalable: {"default": 1},
		http: {
			domains: ["#{system.name}.#{azk.default_domain}"]
		},
		ports: {
			// exports global variables
			http: "80/tcp",
			data: "3306/tcp"
		},
		envs: {
			// Exports global variables
			ENV: "dev"
		},
		export_envs: {
			// exports variables for dependent systems
			APP_URL: "#{system.name}.#{azk.default_domain}:#{net.port.http}"
		},
		/*provision: [
			"npm install",
			"composer install",
			"bower install"
		]*/
	},
	mysql: {
		image: {"docker": "azukiapp/mysql:5.7"},
		shell: "/bin/bash",
		wait: 25,
		mounts: {
			'/var/lib/mysql': persistent("#{manifest.dir}/xmysql"),
		},
		ports: {
			data: "3306/tcp"
		},
		envs: {
			MYSQL_ROOT_PASSWORD: "root",
			MYSQL_USER: "translate",
			MYSQL_PASS: "translate",
			MYSQL_DATABASE: "#{manifest.dir}_dev"
		},
		export_envs: {
			MYSQL_USER: "translate",
			MYSQL_PASS: "translate",
			MYSQL_DATABASE: "#{manifest.dir}_dev"
		}
	},
	"phpmyadmin": {
		depends: ["mysql"],
		image: { docker: "reduto/phpmyadmin" },
		wait: {retry: 20, timeout: 1000},
		scalable: {default: 1, limit: 1},
		http: {
			domains: [ "#{system.name}.#{azk.default_domain}" ]
		},
		ports: {
			http: "80/tcp"
		}
	}
});

// Sets a default system (to use: start, stop, status, scale)
setDefault("web");
